import { CustomResource } from 'aws-cdk-lib';
import { VpcAttributes } from 'aws-cdk-lib/aws-ec2';
import { Cluster, KubernetesVersion, Nodegroup } from 'aws-cdk-lib/aws-eks';
import { CfnVirtualCluster } from 'aws-cdk-lib/aws-emrcontainers';
import { IManagedPolicy, Role } from 'aws-cdk-lib/aws-iam';
import { Bucket, Location } from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
import { TrackedConstruct } from '../common/tracked-construct';
import { EmrEksNodegroup, EmrEksNodegroupOptions } from './emr-eks-nodegroup';
import { EmrManagedEndpointOptions } from './emr-managed-endpoint';
import { EmrVirtualClusterOptions } from './emr-virtual-cluster';
/**
 * The properties for the EmrEksCluster Construct class.
 */
export interface EmrEksClusterProps {
    /**
     * Name of the Amazon EKS cluster to be created
     * @default -  The [default cluster name]{@link EmrEksCluster.DEFAULT_CLUSTER_NAME}
     */
    readonly eksClusterName?: string;
    /**
     * Amazon IAM Role to be added to Amazon EKS master roles that will give access to kubernetes cluster from AWS console UI
     */
    readonly eksAdminRoleArn: string;
    /**
     * List of EmrEksNodegroup to create in the cluster in addition to the default [nodegroups]{@link EmrEksNodegroup}
     * @default -  Don't create additional nodegroups
     */
    readonly emrEksNodegroups?: EmrEksNodegroup[];
    /**
     * Kubernetes version for Amazon EKS cluster that will be created
     * @default -  v1.21 version is used
     */
    readonly kubernetesVersion?: KubernetesVersion;
    /**
     * Attributes of the VPC where to deploy the EKS cluster
     * VPC should have at least two private and public subnets in different Availability Zones
     * All private subnets should have the following tags:
     * 'for-use-with-amazon-emr-managed-policies'='true'
     * 'kubernetes.io/role/internal-elb'='1'
     * All public subnets should have the following tag:
     * 'kubernetes.io/role/elb'='1'
     */
    readonly eksVpcAttributes?: VpcAttributes;
    /**
     * If set to true construct will create default EKS nodegroups. There are three types of Nodegroup:
     *  * Nodegroup for critical jobs which use on-demand instances.
     *  * Nodegroup using spot instances for jobs that are not critical and can be preempted if a spot instance is reclaimed
     *  * Nodegroup to provide capacity for creating and running managed endpoints spark drivers and executors.
     * @default -  true
     */
    readonly defaultNodeGroups?: boolean;
    /**
     * The version of autoscaler to pass to Helm
     * @default -  version matching the default Kubernete version
     */
    readonly autoscalerVersion?: number;
}
/**
 * EmrEksCluster Construct packaging all the resources and configuration required to run Amazon EMR on EKS.
 * It deploys:
 * * An EKS cluster (VPC configuration can be customized)
 * * A tooling nodegroup to run tools including the Kubedashboard and the Cluster Autoscaler
 * * Optionally multiple nodegroups (one per AZ) for critical/shared/notebook EMR workloads
 * * Additional nodegroups can be configured
 *
 * The construct will upload on S3 the Pod templates required to run EMR jobs on the default nodegroups.
 * It will also parse and store the configuration of EMR on EKS jobs for each default nodegroup in object parameters
 *
 * Methods are available to add EMR Virtual Clusters to the EKS cluster and to create execution roles for the virtual clusters.
 *
 * Usage example:
 *
 * ```typescript
 * const emrEks: EmrEksCluster = EmrEksCluster.getOrCreate(stack, {
 *   eksAdminRoleArn: <ROLE_ARN>,
 *   eksClusterName: <CLUSTER_NAME>,
 * });
 *
 * const virtualCluster = emrEks.addEmrVirtualCluster(stack, {
 *   name: <Virtual_Cluster_Name>,
 *   createNamespace: <TRUE OR FALSE>,
 *   eksNamespace: <K8S_namespace>,
 * });
 *
 * const role = emrEks.createExecutionRole(stack, 'ExecRole',{
 *   policy: <POLICY>,
 * })
 *
 * // EMR on EKS virtual cluster ID
 * cdk.CfnOutput(self, 'VirtualClusterId',value = virtualCluster.attr_id)
 * // Job config for each nodegroup
 * cdk.CfnOutput(self, "CriticalConfig", value = emrEks.criticalDefaultConfig)
 * cdk.CfnOutput(self, "SharedConfig", value = emrEks.sharedDefaultConfig)
 * // Execution role arn
 * cdk.CfnOutput(self,'ExecRoleArn', value = role.roleArn)
 * ```
 *
 */
export declare class EmrEksCluster extends TrackedConstruct {
    /**
     * Get an existing EmrEksCluster based on the cluster name property or create a new one
     * only one EKS cluster can exist per stack
     * @param {Construct} scope the CDK scope used to search or create the cluster
     * @param {EmrEksClusterProps} props the EmrEksClusterProps [properties]{@link EmrEksClusterProps} if created
     */
    static getOrCreate(scope: Construct, props: EmrEksClusterProps): EmrEksCluster;
    private static readonly EMR_VERSIONS;
    private static readonly DEFAULT_EMR_VERSION;
    private static readonly DEFAULT_EKS_VERSION;
    private static readonly DEFAULT_CLUSTER_NAME;
    readonly eksCluster: Cluster;
    readonly notebookDefaultConfig: string;
    readonly criticalDefaultConfig: string;
    readonly sharedDefaultConfig: string;
    readonly podTemplateLocation: Location;
    readonly assetBucket: Bucket;
    private readonly managedEndpointProviderServiceToken;
    private readonly nodegroupAsgTagsProviderServiceToken;
    private readonly emrServiceRole;
    private readonly eksOidcProvider;
    private readonly clusterName;
    private readonly eksVpc;
    private readonly assetUploadBucketRole;
    private readonly awsNodeRole;
    private readonly ec2InstanceNodeGroupRole;
    private readonly defaultNodeGroups;
    /**
     * Constructs a new instance of the EmrEksCluster construct.
     * @param {Construct} scope the Scope of the CDK Construct
     * @param {string} id the ID of the CDK Construct
     * @param {EmrEksClusterProps} props the EmrEksClusterProps [properties]{@link EmrEksClusterProps}
     * @access private
     */
    private constructor();
    /**
     * Add new nodegroups to the cluster for Amazon EMR on EKS. This method overrides Amazon EKS nodegroup options then create the nodegroup.
     * If no subnet is provided, it creates one nodegroup per private subnet in the Amazon EKS Cluster.
     * If NVME local storage is used, the user_data is modified.
     * @param {string} id the CDK ID of the resource
     * @param {EmrEksNodegroupOptions} props the EmrEksNodegroupOptions [properties]{@link EmrEksNodegroupOptions}
     */
    addEmrEksNodegroup(id: string, props: EmrEksNodegroupOptions): void;
    /**
     * Add a new Amazon EMR Virtual Cluster linked to Amazon EKS Cluster.
     * @param {Construct} scope of the stack where virtual cluster is deployed
     * @param {EmrVirtualClusterOptions} options the EmrVirtualClusterProps [properties]{@link EmrVirtualClusterProps}
     */
    addEmrVirtualCluster(scope: Construct, options: EmrVirtualClusterOptions): CfnVirtualCluster;
    /**
     * Creates a new Amazon EMR managed endpoint to be used with Amazon EMR Virtual Cluster .
     * CfnOutput can be customized.
     * @param {Construct} scope the scope of the stack where managed endpoint is deployed
     * @param {string} id the CDK id for endpoint
     * @param {EmrManagedEndpointOptions} options the EmrManagedEndpointOptions to configure the Amazon EMR managed endpoint
     */
    addManagedEndpoint(scope: Construct, id: string, options: EmrManagedEndpointOptions): CustomResource;
    /**
     * Add a new Amazon EKS Nodegroup to the cluster.
     * This method is be used to add a nodegroup to the Amazon EKS cluster and automatically set tags based on labels and taints
     *  so it can be used for the cluster autoscaler.
     * @param {string} nodegroupId the ID of the nodegroup
     * @param {EmrEksNodegroupOptions} options the EmrEksNodegroup [properties]{@link EmrEksNodegroupOptions}
     */
    addNodegroupCapacity(nodegroupId: string, options: EmrEksNodegroupOptions): Nodegroup;
    /**
     * Create and configure a new Amazon IAM Role usable as an execution role.
     * This method makes the created role assumed by the Amazon EKS cluster Open ID Connect provider.
     * @param {Construct} scope of the IAM role
     * @param {string} id of the CDK resource to be created, it should be unique across the stack
     * @param {IManagedPolicy} policy the execution policy to attach to the role
     * @param {string} namespace The namespace from which the role is going to be used. MUST be the same as the namespace of the Virtual Cluster from which the job is submitted
     * @param {string} name Name to use for the role, required and is used to scope the iam role
     */
    createExecutionRole(scope: Construct, id: string, policy: IManagedPolicy, namespace: string, name: string): Role;
    /**
     * Upload podTemplates to the Amazon S3 location used by the cluster.
     * @param {string} id the unique ID of the CDK resource
     * @param {string} filePath The local path of the yaml podTemplate files to upload
     */
    uploadPodTemplate(id: string, filePath: string): void;
}
